@@ -906,6 +906,7 @@ def test_test_cli(mocker, tuxsuite_config):
         fip=None,
         parameters={},
         tests=[],
+        timeouts={},
         boot_args=None,
         wait_for=None,
     )
@@ -936,6 +937,7 @@ def test_test_cli(mocker, tuxsuite_config):
         fip=None,
         parameters={},
         tests=["ltp-smoke"],
+        timeouts={},
         boot_args=None,
         wait_for=None,
     )
@@ -965,11 +967,42 @@ def test_test_cli(mocker, tuxsuite_config):
         fip=None,
         parameters={},
         tests=["ltp-smoke"],
+        timeouts={},
         boot_args=None,
         wait_for="mybuilduid",
     )
     assert wait_for_object.call_count == 1
 
+    mocker.resetall()
+    result = runner.invoke(
+        tuxsuite.cli.test,
+        [
+            "--device=qemu-arm64",
+            "--timeouts=deploy=1",
+            "--timeouts=boot=2",
+        ],
+    )
+    assert result.exit_code == 0
+    assert test.call_count == 1
+    test.assert_called_once_with(
+        device="qemu-arm64",
+        kernel=None,
+        ap_romfw=None,
+        mcp_fw=None,
+        mcp_romfw=None,
+        modules=None,
+        rootfs=None,
+        scp_fw=None,
+        scp_romfw=None,
+        fip=None,
+        parameters={},
+        tests=[],
+        timeouts={"deploy": 1, "boot": 2},
+        boot_args=None,
+        wait_for=None,
+    )
+    assert wait_for_object.call_count == 1
+
     mocker.resetall()
     result = runner.invoke(
         tuxsuite.cli.test,
@@ -1003,6 +1036,7 @@ def test_test_cli(mocker, tuxsuite_config):
         fip="fip.bin",
         parameters={"USERDATA": "userdata.tar.xz", "TC_URL": "toolchain.tar.xz"},
         tests=["lldb"],
+        timeouts={},
         boot_args=None,
         wait_for=None,
     )
@@ -1011,20 +1045,8 @@ def test_test_cli(mocker, tuxsuite_config):
 
 def test_test_cli_errors(mocker):
     test = mocker.patch("tuxsuite.Test")
-    wait_for_object = mocker.patch("tuxsuite.cli.wait_for_object")
+    mocker.patch("tuxsuite.cli.wait_for_object")
     runner = CliRunner()
-    result = runner.invoke(
-        tuxsuite.cli.test,
-        [
-            "--device=qemu-arm64",
-            "--tests=something,ltp-smoke",
-        ],
-    )
-    assert result.exit_code == 1
-    assert test.call_count == 0
-    assert wait_for_object.call_count == 0
-
-    mocker.resetall()
     result = runner.invoke(
         tuxsuite.cli.test,
         [
