@@ -305,8 +305,6 @@ class Build(HeadersMixin):
 
         Will timeout after `build_state_timeout` seconds.
         """
-        attempts = 1
-        max_attempts = 3
         waiting_states = {
             "queued": BuildState(
                 build=self,
@@ -342,26 +340,20 @@ class Build(HeadersMixin):
         while True:
             self.get_status()
             state = self.status["state"]
-            result = self.status["result"]
+            retry = self.status.get("retry", 0)
             if state != previous_state:
-                if state in waiting_states:
-                    yield waiting_states[state]
-                elif (
-                    state == "finished"
-                    and result == "error"
-                    and attempts < max_attempts
-                ):
-                    attempts += 1
+                if retry:
                     message = self.status.get("status_message", "infrastructure error")
                     timeout = time.time() + build_state_timeout
                     yield BuildState(
                         build=self,
                         state=self.status["tuxbuild_status"],
-                        message=message
-                        + f" - retrying (attempt {attempts}/{max_attempts})",
+                        message=message + f" - retrying (attempt {retry})",
                         icon="🔧",
                         cli_color="yellow",
                     )
+                elif state in waiting_states:
+                    yield waiting_states[state]
                 elif state == "finished":
                     break
                 else:
@@ -536,8 +528,10 @@ class Plan(HeadersMixin):
                             group=self.group,
                             project=self.project,
                             device=test["device"],
+                            parameters=test.get("parameters", {}),
                             tests=test.get("tests", []),
                             boot_args=test.get("boot_args"),
+                            timeouts=test.get("timeouts"),
                             wait_for=build.uid,
                         )
                     )
@@ -562,6 +556,7 @@ class Plan(HeadersMixin):
                             scp_fw=test.get("scp_fw"),
                             scp_romfw=test.get("scp_romfw"),
                             tests=test.get("tests", []),
+                            timeouts=test.get("timeouts"),
                             fip=test.get("fip"),
                             boot_args=test.get("boot_args"),
                         )
